==> facebook-nodejs-business-sdk-4.0.8.tgz: package/docs/BUSINESS_OWNED_BUSINESSES.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Business = bizSdk.Business;
const AbstractObject = bizSdk.AbstractObject;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let client_access_token = 'EAACovfpTQbcBAEBBfmcaT2VHqZBejCp0ZCOO9rQDXmDptGzI7Vky96HW7jAzVKpaWNBDC4w5ZBY3qf692sXYt1qJwOYfABCvrGEaf6ojT8TWrHIZCEh9m49R8nAyOl7AHliiryKEXxNSpZCzsGiZA5StE9HHxgUMJsEdBfE6lgY3FnBIBPn8tO3UkIwzc53L4MvtVwQJnPOAZDZD';
let partner_bm_id = '249554531892085';
let partner_access_token = 'EAACovfpTQbcBABTpQadL2itCDWd4f3gZCZBIqdIweJZCXteBs7FZArku6pYNR3aiQHjs4ZCyE7sF8V29tMY7uJYIwvJKcQmfSF2AQbHshvlM4PaVZBexeDXv3ZAn1zBrajwaoV5yEy9VK2soWl52t45Oda1jygia4G4cAbASH7OZAFYZCC1RZC5eM0PF4CzIj3LikQSZA7K5ZCrEkAZDZD';
const api = bizSdk.FacebookAdsApi.init(
  client_access_token
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [BUSINESS_OWNED_BUSINESSES_CREATE]
//  _DOC vars [client_access_token]
//  _DOC vars [partner_bm_id]
fields = [
];
params = {
  'name' : 'Test brand name',
  'timezone_id' : '10',
  'vertical' : 'OTHER',
  'survey_business_type' : 'AGENCY',
  'survey_num_people' : '500',
  'survey_num_assets' : '1000',
  'sales_rep_email' : 'rep@sales.fb.com',
};
let child_business = await (new Business(partner_bm_id)).createOwnedBusiness(
  fields,
  params
);
let child_business_id = child_business.id;
bizSdk.FacebookAdsApi.init(partner_access_token);
fields = [
];
params = {
  'client_id' : child_business_id,
};
await (new Business(partner_bm_id)).deleteOwnedBusinesses(
  params
);

//  _DOC close [BUSINESS_OWNED_BUSINESSES_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();

==> facebook-nodejs-business-sdk-6.0.0.tgz: package/docs/BUSINESS_OWNED_BUSINESSES.js <==
/**
 * Copyright (c) 2017-present, Facebook, Inc.
 * All rights reserved.
 *
 * This source code is licensed under the license found in the
 * LICENSE file in the root directory of this source tree.
 * @flow
 */

const bizSdk = require('facebook-nodejs-business-sdk');
const process = require('process');
const Business = bizSdk.Business;
const AbstractObject = bizSdk.AbstractObject;

let app_id = '1224202007596125';
let access_token = 'EAARZAZA73LzF0BACZADSZCYwMsLHUTwAAYKm5Tciz5GZCGM8ZAtqoM12q8ybFt6dpElSqbUuXm77dGmZAeK6r1wygAQZCslDqpsVQY6RQA3WhLirP8BcgoKoCTvlyKzkx6xGPZCcRiDXUleDqSbnAQBd5k0ZBhuLf1AB2VsIS5OlYDoTQlOoRuVpmZAiJY9O6d688sZD';
let app_secret = '709348c9665c33a4f988ff3950098131';
let client_access_token = 'EAACovfpTQbcBAEBBfmcaT2VHqZBejCp0ZCOO9rQDXmDptGzI7Vky96HW7jAzVKpaWNBDC4w5ZBY3qf692sXYt1qJwOYfABCvrGEaf6ojT8TWrHIZCEh9m49R8nAyOl7AHliiryKEXxNSpZCzsGiZA5StE9HHxgUMJsEdBfE6lgY3FnBIBPn8tO3UkIwzc53L4MvtVwQJnPOAZDZD';
let partner_bm_id = '249554531892085';
let partner_access_token = 'EAACovfpTQbcBABTpQadL2itCDWd4f3gZCZBIqdIweJZCXteBs7FZArku6pYNR3aiQHjs4ZCyE7sF8V29tMY7uJYIwvJKcQmfSF2AQbHshvlM4PaVZBexeDXv3ZAn1zBrajwaoV5yEy9VK2soWl52t45Oda1jygia4G4cAbASH7OZAFYZCC1RZC5eM0PF4CzIj3LikQSZA7K5ZCrEkAZDZD';
const api = bizSdk.FacebookAdsApi.init(
  client_access_token,
  crash_log=false
);
const showDebugingInfo = true; // Setting this to true shows more debugging info.
if (showDebugingInfo) {
  api.setDebug(true);
}

const logApiCallResult = (apiCallName, data) => {
  console.log(apiCallName);
  if (showDebugingInfo) {
    console.log('Data:' + JSON.stringify(data));
  }
};
let fields, params;
void async function() {
try {
//  _DOC oncall [business_api]
//  _DOC open [BUSINESS_OWNED_BUSINESSES_CREATE]
//  _DOC vars [client_access_token]
//  _DOC vars [partner_bm_id]
fields = [
];
params = {
  'name' : 'Test brand name',
  'timezone_id' : '10',
  'vertical' : 'OTHER',
  'survey_business_type' : 'AGENCY',
  'survey_num_people' : '500',
  'survey_num_assets' : '1000',
  'sales_rep_email' : 'rep@sales.fb.com',
};
let child_business = await (new Business(partner_bm_id)).createOwnedBusiness(
  fields,
  params
);
let child_business_id = child_business.id;
bizSdk.FacebookAdsApi.init(partner_access_token, crash_log=false);
fields = [
];
params = {
  'client_id' : child_business_id,
};
await (new Business(partner_bm_id)).deleteOwnedBusinesses(
  params
);

//  _DOC close [BUSINESS_OWNED_BUSINESSES_CREATE]
}
catch(error) {
  console.log(error);
  process.exit(1);
}
}();
